  ----------------------------------------------------------------------------------------------------------------------
    -- This program is free software: you can redistribute it and/or modify
    -- it under the terms of the GNU General Public License as published by
    -- the Free Software Foundation, either version 3 of the License, or
    -- (at your option) any later version.
	
    -- This program is distributed in the hope that it will be useful,
    -- but WITHOUT ANY WARRANTY; without even the implied warranty of
    -- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    -- GNU General Public License for more details.

    -- You should have received a copy of the GNU General Public License
    -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
----------------------------------------------------------------------------------------------------------------------

local addonName, T = ...


-- [[ Number formatting ]] --

	 -- Format number as short (15365 = 15.3k etc.) -> All credit goes to Google and whoever wrote it on wowinterface (I think?). I did NOT reinvent the wheel here!
	 local function Short(value,format) 
		if type(value) == "number" then
			local fmt
			if value >= 1000000000 or value <= -1000000000 then
				fmt = "%.1fb"
				value = value / 1000000000
			elseif value >= 10000000 or value <= -10000000 then
				fmt = "%.1fm"
				value = value / 1000000
			elseif value >= 1000000 or value <= -1000000 then
				fmt = "%.2fm"
				value = value / 1000000
			elseif value >= 100000 or value <= -100000 then
				fmt = "%.0fk"
				value = value / 1000
			elseif value >= 10000 or value <= -10000 then
				fmt = "%.1fk"
				value = value / 1000
			else
				fmt = "%d"
				value = math.floor(value + 0.5)
			end
			if format then
				return fmt:format(value)
			end
			return fmt, value
		else
			local fmt_a, fmt_b
			local a, b = value:match("^(%d+)/(%d+)$")
			if a then
				a, b = tonumber(a), tonumber(b)
				if a >= 1000000000 or a <= -1000000000 then
					fmt_a = "%.1fb"
					a = a / 1000000000
				elseif a >= 10000000 or a <= -10000000 then
					fmt_a = "%.1fm"
					a = a / 1000000
				elseif a >= 1000000 or a <= -1000000 then
					fmt_a = "%.2fm"
					a = a / 1000000
				elseif a >= 100000 or a <= -100000 then
					fmt_a = "%.0fk"
					a = a / 1000
				elseif a >= 10000 or a <= -10000 then
					fmt_a = "%.1fk"
					a = a / 1000
				end
				if b >= 1000000000 or b <= -1000000000 then
					fmt_b = "%.1fb"
					b = b / 1000000000
				elseif b >= 10000000 or b <= -10000000 then
					fmt_b = "%.1fm"
					b = b / 1000000
				elseif b >= 1000000 or b <= -1000000 then
					fmt_b = "%.2fm"
					b = b / 1000000
				elseif b >= 100000 or b <= -100000 then
					fmt_b = "%.0fk"
					b = b / 1000
				elseif b >= 10000 or b <= -10000 then
					fmt_b = "%.1fk"
					b = b / 1000
				end
				local fmt = ("%s/%s"):format(fmt_a, fmt_b)
				if format then
					return fmt:format(a, b)
				end
				return fmt, a, b
			else
				return value
			end
		end
	end


-- [[ Message formatting ]] --

	-- Print debug messages (if enabled)
	local function Debug(msg)
		if TotalArtifactPowerSettings.debugMode then
			print(format("|c000072CA" .. "%s-Debug: " .. "|c00E6CC80%s", addonName, msg)); 
		end
	end
			
	-- Print regular addon messages (if enabled)
	local function ChatMsg(msg)
		if TotalArtifactPowerSettings.verbose then
			print(format("|c00CC5500" .. "%s: " .. "|c00E6CC80%s", addonName, msg)); 
		end
	end


-- Make functions available in the addon's namespace  (T is the addonTable)
if not T then return end
T.Short = Short
T.Debug = Debug
T.ChatMsg = ChatMsg

-- Not really necessary, I guess, but proper style regardless (require isn't working in WOW's Lua environment)
local Format = {
	Short,
	Debug,
	ChatMsg
}

return Format